; HTML5 Slider GUI demo for all size Android smartphones and tablets
; Requires Android OS 4.2.2+, and Csound6[.05].apk or higher
;   Downloadable from
; http://sourceforge.net/projects/csound/files/csound6/Csound6.05/
; or http://sourceforge.net/projects/csound/files/csound6/Csound6.06/ 
;   (as CsoundApplication-release.apk)
; Android OS < 5.0 requires the 6.05 download
; No Csound code included

; Suggestion: place all HTML outside Csound code at beginning or end of .csd.
; Doing so will happily eliminate it from Csound console output

<html>
<head>
<style type="text/css">

/* eliminates accidental text selection by user in performance */
.noselect {
        -webkit-user-select: none;
}

input[type='range'] {
	-webkit-appearance: none;
	background-color: silver; /* user choice */
	height: 70%;
    	width: 95%; 
}
input[type='range']::-webkit-slider-thumb {
    	-webkit-appearance: none;
    	width: 10px;  /* user choice */
	height: 120%;
    	background: white; /* user choice */
}

/* text in slider labels is centered */
table td {
	text-align: center;
	color: white;
	background-color: teal; /* user choice */
}

</style>

</head>
<body>

<!-- enclose entire body within a single <div> tag
so that all text is protected against accidental selection --!>
<div class="noselect">

<!-- avoid headline fonts; they take up valuable vertical space --!>
<!-- use *relative*, not absolute font-sizes; relative sizes scale to display --!>
<big><big><big><b>HTML5 SLIDER GUI</b></big></big></big><br>
<br><br>
<table>
<colgroup>
  <col width="">
  <col width="100%">
</colgroup>
<tr>
<td>
	<div class="slider_height">
<label for=slider1>Slider1</label>
</div>
</td>
<td>
<!-- step=0.001 simulates infinite, smooth slider movement --!>
<input type=range min=0 max=1 value=0 id=slider1 step=0.001 oninput="slider1(value)">
</td>
</tr>
<tr>
<td>
	<div class="slider_height">
<label for=slider2>Slider2</label>
</div>
</td>
<td>
<!-- though the normal Csound Android slider range is 0 to 1, webkit default is actually 0 to 100 --!>
<!-- range can actually be anything; value = initial slider placement,
     though *there is no actual output until slider is moved* --!>
<input type=range min=0 max=100 value=0 id=slider2  step=0.001 oninput="slider2(value)">
</td>
</tr>
</table>
<br>

<table>
<colgroup> <!-- this table set up for 3 columns --!>
  <col width=""> <!-- = space autoadjusts to that required by the longest string in the label --!>
<!-- NOTE: strings are separated by spaces, dashes and forward slashes only --!>  
  <col width="100%"> <!-- 100% = all space left over! --!>
  <col width=""> <!-- space autoadjusts to the # of digits displayed in this column --!>
<!-- all data in this column should contain the same # of digits --!>
</colgroup>
<tr>
<td>
	<div class="slider_height">
<!-- note that space after Slider breaks string into two, shorter lines of text --!>
<label for=fader3>Slider 3</label>
</div>
</td>
<td>
<input type=range min=0 max=1 value=0 id=fader3 step=0.001 oninput="fader3(value)">
<!-- column three [displayed value] is omitted for this slider --!>
</td>
</tr>
<tr>
<td>
	<div class="slider_height">
<label for=fader4>Slider 4</label>
</div>
</td>
<td>
<!-- note that min (and start) value do not have to be 0; but if start value <> 0, this variable must be initialized by Csound to start value, as its value is only sent once slider is moved.
     Example for fader4 below: in Csound, "kamp chnget displayfader4" must be preceeded by "kamp init 1" --!>
<!-- also note: chnget must be placed within an instrument, and chnset and chnexport are not implemented --!> 
<!-- keep max value < 10.00 to remain within the space occupied by the lowest (and initial) value 1.00 --!>
<input type=range min=1 max=3.8 value=1 id=displayfader4 step=0.001 oninput="fader4(value)">
</td>
<td>
<!-- # of digits in initial output = fixed decimal places (2) + 1 --!>
<output for=fader4 id=displayfader4Output>1.00</output>
</td>
</tr>
</table>

<script>

/* adjust slider height (% of screen) here */
var slider_height_fraction = 0.14;

var screen_height = Math.max(document.documentElement.clientHeight, window.innerHeight || 0);
var screen_width = Math.max(document.documentElement.clientWidth, window.innerWidth || 0);
var elements = document.getElementsByClassName("slider_height");
Array.prototype.forEach.call(elements, function(element) {
	element.setAttribute("style", "height: "+ screen_height * slider_height_fraction +"px;");
});

function slider1(value) {
	var numberValue = parseFloat(value);
	csound.setControlChannel('slider1', numberValue);
}
function slider2(value) {
	var numberValue = parseFloat(value);
	csound.setControlChannel('slider2', numberValue);
}
function fader3(value) {
	var numberValue = parseFloat(value);
	csound.setControlChannel('fader3', numberValue);
}
function fader4(value) {
	var numberValue = parseFloat(value);
/* value of fader is displayed in column3; toFixed(2) rounds # to two decimal points */
/* this is not MIDI, and raw output could display many, and varied decimal places */
/* the # of fixed decimal places of displayed values, same table, should be identical */
	document.querySelector('#displayfader4Output').value = numberValue.toFixed(2);
	csound.setControlChannel('displayfader4', numberValue);
}

</script>

</div>
</body>
</html>