; NoisePad is a basic Android Csound trackpad demo
;   It does not deal with touchmove and constraining (or not) x and y 
;   values to those within trackpad range. For touchmove and how to
;   handle values "out of range", see the following example:
;   Csound HTML5 GUI Clone with Trackpad.csd
;   Note: the "canonical" Android trackpad does not constrain y values.
: For Android OS < 5.0, change the (chnget) *channel names*
;   trackpad.x & trackpad.y to trackpadx & trackpady,
;   or any name without a dot (6 instances).

<CsoundSynthesizer>
<CsOptions>

-odac -m0d

</CsOptions>
<CsInstruments>

sr      = 44100 ; Sample Rate
ksmps   = 100
nchnls  = 2

        instr 1

ktrig	chnget "trackpad.x"
kamp	chnget "trackpad.y"
ktrig2	 trigger  ktrig, 0, 0
	if ktrig2 == 1 then
kpch	= int(800 + (ktrig * 12.99)) * .01
kamp2	= 1000 + (kamp * 22000)
	event "i", 2, 0, 1.5, kamp2, kpch
	endif
	endin
        
        instr 2
        
kamp	expseg 10, .05, p4, p3 - .05, 10
anoise	noise kamp, 0
ifreq	= cpspch(p5)
a1	reson anoise, ifreq, ifreq * .1, 2
	outs a1, a1
        
        endin

</CsInstruments>
<CsScore>

i 1 0 3600

e

</CsScore>
</CsoundSynthesizer>

<html>
<head>
<style type="text/css">

.noselect {
	-webkit-user-select: none;
}

</style>

</head>
<body>

<div class="noselect">

<big><big><big><b>NOISEPAD</b></big></big></big><br>
 &nbsp; Demo HTML5 trackpad "drumset"
<br><br>

<div align="center">
Trackpad - x=center freq of drums y=amplitude

<canvas id="trackpad" style="background-color: teal;"></canvas>
</div>

<script>

/* adjust trackpad dimensions (% of screen) here */
var trackpad_height_fraction = 0.5;
var trackpad_width_fraction = 0.9;

/* adjust color of trackpad-when-touched  */
var trackpad_touch_color = "cadetblue";

var trackpad = document.getElementById("trackpad");
var context = trackpad.getContext('2d');
var screen_height = Math.max(document.documentElement.clientHeight, window.innerHeight || 0);
var screen_width = Math.max(document.documentElement.clientWidth, window.innerWidth || 0);
trackpad.width = Math.round(screen_width * trackpad_width_fraction);
trackpad.height = Math.round(screen_height * trackpad_height_fraction);

function getTouchPos(event) {
  var rect = trackpad.getBoundingClientRect();
  var x = Math.round((event.targetTouches[0].clientX-rect.left)/(rect.right-rect.left)*trackpad.width);
  var y = Math.round((event.targetTouches[0].clientY-rect.top)/(rect.bottom-rect.top)*trackpad.height);
  var scaled_x = x/(rect.right-rect.left);
  var scaled_y = (rect.bottom-rect.top-y)/(rect.bottom-rect.top);

/* since touchmove is not in play, there is no need in this case to test for x and y values out of trackpad bounds, and thus no need to allow or constrain them */ 

  return {
	x: x,
	y: y,
	scaled_x: scaled_x,
	scaled_y: scaled_y
  };
}
function doTouch(event) {
	event.preventDefault();
	var touch = getTouchPos(event);
	csound.setControlChannel('trackpad.x', touch.scaled_x);
	csound.setControlChannel('trackpad.y', touch.scaled_y);
	trackpad.style.backgroundColor=trackpad_touch_color;
}
function resetZero(event) {
	event.preventDefault();
	csound.setControlChannel('trackpad.x', 0.0);
	csound.setControlChannel('trackpad.y', 0.0);
	context.clearRect(0, 0, trackpad.width, trackpad.height);
	trackpad.style.backgroundColor="teal";
}

trackpad.addEventListener("touchstart", doTouch);
trackpad.addEventListener("touchend", resetZero);

</script>

</div>
</body>
</html>
